@@ -1,23 +1,26 @@
 import logging
+import urllib
+import urllib2
 
 import django
 from django.conf import settings
 from django.utils.hashcompat import md5_constructor
 
+from sentry import conf
+
 _FILTER_CACHE = None
 def get_filters():
     global _FILTER_CACHE
     
     if _FILTER_CACHE is None:
-        from sentry import settings
         
         filters = []
-        for filter_ in settings.FILTERS:
+        for filter_ in conf.FILTERS:
             module_name, class_name = filter_.rsplit('.', 1)
             try:
                 module = __import__(module_name, {}, {}, class_name)
                 filter_ = getattr(module, class_name)
-            except Exception, exc:
+            except Exception:
                 logging.exception('Unable to import %s' % (filter_,))
                 continue
             filters.append(filter_)
@@ -135,4 +138,12 @@ class cached_property(object):
         if value is _missing:
             value = self.func(obj)
             obj.__dict__[self.__name__] = value
-        return value
\ No newline at end of file
+        return value
+
+def urlread(url, get={}, post={}, headers={}, timeout=None):
+    req = urllib2.Request(url, urllib.urlencode(get), headers=headers)
+    try:
+        response = urllib2.urlopen(req, urllib.urlencode(post), timeout).read()
+    except:
+        response = urllib2.urlopen(req, urllib.urlencode(post)).read()
+    return response
\ No newline at end of file
