@@ -16,7 +16,7 @@ from django.utils.encoding import smart_unicode
 from django.utils.translation import ugettext_lazy as _
 
 from sentry import conf
-from sentry.helpers import cached_property, construct_checksum, get_db_engine, transform
+from sentry.helpers import cached_property, construct_checksum, get_db_engine, transform, get_filters
 from sentry.manager import GroupedMessageManager, SentryManager
 from sentry.reporter import FakeRequest
 
@@ -26,6 +26,8 @@ for r in _reqs:
         raise ImproperlyConfigured("Put '%s' in your "
             "INSTALLED_APPS setting in order to use the sentry application." % r)
 
+from indexer.models import Index
+
 try:
     from idmapper.models import SharedMemoryModel as Model
 except ImportError:
@@ -75,6 +77,7 @@ class MessageBase(Model):
     traceback       = models.TextField(blank=True, null=True)
     view            = models.CharField(max_length=200, blank=True, null=True)
     checksum        = models.CharField(max_length=32)
+    data            = GzippedDictField(blank=True, null=True)
 
     objects         = SentryManager()
 
@@ -217,7 +220,6 @@ class GroupedMessage(MessageBase):
 class Message(MessageBase):
     group           = models.ForeignKey(GroupedMessage, blank=True, null=True, related_name="message_set")
     datetime        = models.DateTimeField(default=datetime.datetime.now, db_index=True)
-    data            = GzippedDictField(blank=True, null=True)
     url             = models.URLField(verify_exists=False, null=True, blank=True)
     server_name     = models.CharField(max_length=128, db_index=True)
     site            = models.CharField(max_length=128, db_index=True, null=True)
@@ -283,6 +285,19 @@ class FilterValue(models.Model):
     class Meta:
         unique_together = (('key', 'value'),)
 
+### Helper methods
+
+def register_indexes():
+    """
+    Grabs all required indexes from filters and registers them.
+    """
+    logger = logging.getLogger('sentry.setup')
+    for filter_ in get_filters():
+        if filter_.column.startswith('data__'):
+            Index.objects.register_model(Message, filter_.column, index_to='group')
+            logger.debug('Registered index for for %s' % filter_.column)
+register_indexes()
+
 # XXX: Django sucks and we can't listen to our specific app
 # post_syncdb.connect(GroupedMessage.create_sort_index, sender=__name__)
 post_syncdb.connect(GroupedMessage.create_sort_index, sender=sys.modules[__name__])
\ No newline at end of file
