@@ -4,10 +4,10 @@ from django.test import TestCase
 
 from sentry.models import GroupedMessage
 from sentry.plugins.sentry_redmine import conf
-from sentry.plugins.sentry_redmine.models import CreateRedmineIssue
+from sentry.plugins.sentry_redmine.models import CreateRedmineIssue, RedmineIssue
 
 class CreateIssueTest(TestCase):
-    fixtures = ['sentry/plugins/redmine/tests/fixtures/regression.json']
+    fixtures = ['sentry/plugins/sentry_redmine/tests/fixtures/regression.json']
     urls = 'sentry.urls'
 
     def setUp(self):
@@ -29,7 +29,11 @@ class CreateIssueTest(TestCase):
         response = self.client.post(CreateRedmineIssue.get_url(group.pk), {
             'subject': 'test',
             'description': 'foo',
-        })
+        }, follow=True)
         self.assertEquals(response.status_code, 200)
-        self.assertTemplateUsed(response, 'sentry/plugins/redmine/create_issue.html')
-        
\ No newline at end of file
+        self.assertTemplateUsed(response, 'sentry/group/details.html')
+        
+        self.assertTrue(RedmineIssue.objects.filter(group=group).exists())
+        
+        group = GroupedMessage.objects.get(pk=group.pk)
+        self.assertTrue(group.data['redmine']['issue_id'] > 0)
\ No newline at end of file
